aboutsummaryrefslogtreecommitdiff
path: root/src/core/or/or.h
diff options
context:
space:
mode:
authorMike Perry <mikeperry-git@torproject.org>2019-08-12 13:15:31 -0500
committerMike Perry <mikeperry-git@torproject.org>2019-08-12 14:06:08 -0500
commitb2821b72bc4e228934b5187ae5015230e7cbd26b (patch)
tree5b91a58246f75f0a50d914432cd75e76e738b430 /src/core/or/or.h
parentb14bb12e39d3ccb95a9e5d9cf3eda8428c129520 (diff)
downloadtor-b2821b72bc4e228934b5187ae5015230e7cbd26b.tar.gz
tor-b2821b72bc4e228934b5187ae5015230e7cbd26b.zip
Bug 31356: Propogate protover padding support to circpad
Diffstat (limited to 'src/core/or/or.h')
-rw-r--r--src/core/or/or.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/core/or/or.h b/src/core/or/or.h
index db6d089582..ab258629a6 100644
--- a/src/core/or/or.h
+++ b/src/core/or/or.h
@@ -841,8 +841,8 @@ typedef struct protover_summary_flags_t {
unsigned int supports_v3_rendezvous_point: 1;
/** True iff this router has a protocol list that allows clients to
- * negotiate link-level padding. Requires Padding>=1. */
- unsigned int supports_padding : 1;
+ * negotiate hs circuit setup padding. Requires Padding>=2. */
+ unsigned int supports_hs_setup_padding : 1;
} protover_summary_flags_t;
typedef struct routerinfo_t routerinfo_t;